==> vonage_cloud_runtime-1.1.0-py3-none-any.whl: vonage_cloud_runtime/providers/scheduler/contracts/startAtPayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from vonage_cloud_runtime.session.contracts.IWrappedCallback import IWrappedCallback
from vonage_cloud_runtime.providers.scheduler.contracts.IIntervalParams import IIntervalParams
from vonage_cloud_runtime.providers.scheduler.contracts.IStartAtPayload import IStartAtPayload
T = TypeVar('T')
T = TypeVar("T")

@dataclass
class StartAtPayload(IStartAtPayload,Generic[T]):
    callback: IWrappedCallback
    startAt: str
    interval: IIntervalParams = None
    payload: T = None
    id: str = None
    def __init__(self):
        pass
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result

==> vonage_cloud_runtime-1.4.0b1-py3-none-any.whl: vonage_cloud_runtime/providers/scheduler/contracts/startAtPayload.py <==
from dataclasses import dataclass, field, asdict
from typing import Dict, List, Generic, TypeVar
from abc import ABC, abstractmethod

from vonage_cloud_runtime.session.contracts.IWrappedCallback import IWrappedCallback
from vonage_cloud_runtime.providers.scheduler.contracts.IIntervalParams import IIntervalParams
from vonage_cloud_runtime.providers.scheduler.contracts.IStartAtPayload import IStartAtPayload
T = TypeVar('T')
T = TypeVar("T")

@dataclass
class StartAtPayload(IStartAtPayload,Generic[T]):
    callback: IWrappedCallback
    startAt: str
    interval: IIntervalParams = None
    payload: T = None
    id: str = None
    def __init__(self):
        pass
    def reprJSON(self):
        result = {}
        dict = asdict(self)
        keywordsMap = {"from_":"from","del_":"del","import_":"import","type_":"type", "return_":"return"}
        for key in dict:
            val = getattr(self, key)

            if val is not None:
                if type(val) is list:
                    parsedList = []
                    for i in val:
                        if hasattr(i,'reprJSON'):
                            parsedList.append(i.reprJSON())
                        else:
                            parsedList.append(i)
                    val = parsedList

                if hasattr(val,'reprJSON'):
                    val = val.reprJSON()
                if key in keywordsMap:
                    key = keywordsMap[key]
                result.__setitem__(key.replace('_hyphen_', '-'), val)
        return result
